@@ -15,9 +15,9 @@ import salt.utils.path
 import salt.utils.platform
 import salt.utils.stringutils
 from saltfactories.utils.ports import get_unused_localhost_port
+from saltfactories.utils.tempfiles import temp_file
 from tests.support.case import ModuleCase
 from tests.support.helpers import with_tempfile
-from tests.support.pytest.helpers import temp_state_file
 from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import skipIf
 
@@ -64,7 +64,8 @@ class CPModuleTest(ModuleCase):
 
     @with_tempfile()
     @skipIf(
-        salt.utils.platform.is_windows(), "This test hangs on Windows on Py3",
+        salt.utils.platform.is_windows(),
+        "This test hangs on Windows on Py3",
     )
     def test_get_file_templated_paths(self, tgt):
         """
@@ -233,7 +234,7 @@ class CPModuleTest(ModuleCase):
         """
         cp.get_url with https:// source given
         """
-        self.run_function("cp.get_url", ["https://repo.saltstack.com/index.html", tgt])
+        self.run_function("cp.get_url", ["https://repo.saltproject.io/index.html", tgt])
         with salt.utils.files.fopen(tgt, "r") as instructions:
             data = salt.utils.stringutils.to_unicode(instructions.read())
         self.assertIn("Bootstrap", data)
@@ -246,7 +247,9 @@ class CPModuleTest(ModuleCase):
         """
         cp.get_url with https:// source given and destination omitted.
         """
-        ret = self.run_function("cp.get_url", ["https://repo.saltstack.com/index.html"])
+        ret = self.run_function(
+            "cp.get_url", ["https://repo.saltproject.io/index.html"]
+        )
 
         with salt.utils.files.fopen(ret, "r") as instructions:
             data = salt.utils.stringutils.to_unicode(instructions.read())
@@ -266,13 +269,13 @@ class CPModuleTest(ModuleCase):
         tgt = None
         while time.time() - start <= timeout:
             ret = self.run_function(
-                "cp.get_url", ["https://repo.saltstack.com/index.html", tgt]
+                "cp.get_url", ["https://repo.saltproject.io/index.html", tgt]
             )
             if ret.find("HTTP 599") == -1:
                 break
             time.sleep(sleep)
         if ret.find("HTTP 599") != -1:
-            raise Exception("https://repo.saltstack.com/index.html returned 599 error")
+            raise Exception("https://repo.saltproject.io/index.html returned 599 error")
         self.assertIn("Bootstrap", ret)
         self.assertIn("Debian", ret)
         self.assertIn("Windows", ret)
@@ -310,7 +313,10 @@ class CPModuleTest(ModuleCase):
         """
         self.run_function(
             "cp.get_url",
-            ["ftp://ftp.freebsd.org/pub/FreeBSD/releases/amd64/README.TXT", tgt],
+            [
+                "ftp://ftp.freebsd.org/pub/FreeBSD/releases/amd64/README.TXT",
+                tgt,
+            ],
         )
         with salt.utils.files.fopen(tgt, "r") as instructions:
             data = salt.utils.stringutils.to_unicode(instructions.read())
@@ -341,7 +347,7 @@ class CPModuleTest(ModuleCase):
         """
         cp.get_file_str with https:// source given
         """
-        src = "https://repo.saltstack.com/index.html"
+        src = "https://repo.saltproject.io/index.html"
         ret = self.run_function("cp.get_file_str", [src])
         self.assertIn("Bootstrap", ret)
         self.assertIn("Debian", ret)
@@ -391,7 +397,10 @@ class CPModuleTest(ModuleCase):
         """
         cp.cache_master
         """
-        ret = self.run_function("cp.cache_master", [tgt],)
+        ret = self.run_function(
+            "cp.cache_master",
+            [tgt],
+        )
         for path in ret:
             self.assertTrue(os.path.exists(path))
 
@@ -511,10 +520,12 @@ class CPModuleTest(ModuleCase):
             RUNTIME_VARS.TMP
         )
 
-        with temp_state_file("top.sls", top_sls), temp_state_file(
-            "core.sls", core_state
-        ):
-            ret = self.run_function("cp.list_states",)
+        with temp_file(
+            "top.sls", top_sls, RUNTIME_VARS.TMP_BASEENV_STATE_TREE
+        ), temp_file("core.sls", core_state, RUNTIME_VARS.TMP_BASEENV_STATE_TREE):
+            ret = self.run_function(
+                "cp.list_states",
+            )
             self.assertIn("core", ret)
             self.assertIn("top", ret)
 
