@@ -23,7 +23,7 @@ import salt.utils.process
 import salt.utils.stringutils
 from salt.master import SMaster
 from salt.transport.zeromq import AsyncReqMessageClientPool
-from tests.support.mock import MagicMock, call, patch
+from tests.support.mock import MagicMock, create_autospec, patch
 
 try:
     from M2Crypto import RSA
@@ -38,7 +38,6 @@ except ImportError:
 
 log = logging.getLogger(__name__)
 
-
 MASTER_PRIV_KEY = """
 -----BEGIN RSA PRIVATE KEY-----
 MIIEogIBAAKCAQEAoAsMPt+4kuIG6vKyw9r3+OuZrVBee/2vDdVetW+Js5dTlgrJ
@@ -302,23 +301,6 @@ def test_master_uri():
         ) == "tcp://0.0.0.0:{};{}:{}".format(s_port, m_ip, m_port)
 
 
-def test_force_close_all_instances():
-    zmq1 = MagicMock()
-    zmq2 = MagicMock()
-    zmq3 = MagicMock()
-    zmq_objects = {"zmq": {"1": zmq1, "2": zmq2}, "other_zmq": {"3": zmq3}}
-
-    with patch("salt.transport.zeromq.AsyncZeroMQReqChannel.instance_map", zmq_objects):
-        salt.transport.zeromq.AsyncZeroMQReqChannel.force_close_all_instances()
-
-        assert zmq1.mock_calls == [call.close()]
-        assert zmq2.mock_calls == [call.close()]
-        assert zmq3.mock_calls == [call.close()]
-
-        # check if instance map changed
-        assert zmq_objects is salt.transport.zeromq.AsyncZeroMQReqChannel.instance_map
-
-
 def test_async_req_message_client_pool_send():
     sock_pool_size = 5
     with patch(
@@ -401,7 +383,9 @@ def test_zeromq_async_pub_channel_publish_port(temp_salt_master):
     assert str(opts["publish_port"]) in patch_socket.mock_calls[0][1][0]
 
 
-def test_zeromq_async_pub_channel_filtering_decode_message_no_match(temp_salt_master,):
+def test_zeromq_async_pub_channel_filtering_decode_message_no_match(
+    temp_salt_master,
+):
     """
     test AsyncZeroMQPubChannel _decode_messages when
     zmq_filtering enabled and minion does not match
@@ -523,7 +507,7 @@ def test_req_server_chan_encrypt_v2(pki_dir):
 
     assert "sig" in signed_msg
     assert "data" in signed_msg
-    data = salt.payload.Serial({}).loads(signed_msg["data"])
+    data = salt.payload.loads(signed_msg["data"])
     assert "key" in data
     assert data["key"] == ret["key"]
     assert "key" in data
@@ -624,6 +608,7 @@ async def test_req_chan_decode_data_dict_entry_v2(pki_dir):
     auth = client.auth
     auth._crypticle = salt.crypt.Crypticle(opts, AES_KEY)
     client.auth = MagicMock()
+    client.auth.mpub = auth.mpub
     client.auth.authenticated = True
     client.auth.get_keys = auth.get_keys
     client.auth.crypticle.dumps = auth.crypticle.dumps
@@ -653,7 +638,10 @@ async def test_req_chan_decode_data_dict_entry_v2(pki_dir):
         "ver": "2",
         "cmd": "_pillar",
     }
-    ret = await client.crypted_transfer_decode_dictentry(load, dictkey="pillar",)
+    ret = await client.crypted_transfer_decode_dictentry(
+        load,
+        dictkey="pillar",
+    )
     assert "version" in client.message_client.msg
     assert client.message_client.msg["version"] == 2
     assert ret == {"pillar1": "meh"}
@@ -685,6 +673,7 @@ async def test_req_chan_decode_data_dict_entry_v2_bad_nonce(pki_dir):
     auth = client.auth
     auth._crypticle = salt.crypt.Crypticle(opts, AES_KEY)
     client.auth = MagicMock()
+    client.auth.mpub = auth.mpub
     client.auth.authenticated = True
     client.auth.get_keys = auth.get_keys
     client.auth.crypticle.dumps = auth.crypticle.dumps
@@ -715,7 +704,10 @@ async def test_req_chan_decode_data_dict_entry_v2_bad_nonce(pki_dir):
     }
 
     with pytest.raises(salt.crypt.AuthenticationError) as excinfo:
-        ret = await client.crypted_transfer_decode_dictentry(load, dictkey="pillar",)
+        ret = await client.crypted_transfer_decode_dictentry(
+            load,
+            dictkey="pillar",
+        )
     assert "Pillar nonce verification failed." == excinfo.value.message
 
 
@@ -745,6 +737,7 @@ async def test_req_chan_decode_data_dict_entry_v2_bad_signature(pki_dir):
     auth = client.auth
     auth._crypticle = salt.crypt.Crypticle(opts, AES_KEY)
     client.auth = MagicMock()
+    client.auth.mpub = auth.mpub
     client.auth.authenticated = True
     client.auth.get_keys = auth.get_keys
     client.auth.crypticle.dumps = auth.crypticle.dumps
@@ -769,10 +762,9 @@ async def test_req_chan_decode_data_dict_entry_v2_bad_signature(pki_dir):
         signed_msg = pcrypt.loads(ret[dictkey])
         # Changing the pillar data will cause the signature verification to
         # fail.
-        serial = salt.payload.Serial({})
-        data = serial.loads(signed_msg["data"])
+        data = salt.payload.loads(signed_msg["data"])
         data["pillar"] = {"pillar1": "bar"}
-        signed_msg["data"] = serial.dumps(data)
+        signed_msg["data"] = salt.payload.dumps(data)
         ret[dictkey] = pcrypt.dumps(signed_msg)
         raise salt.ext.tornado.gen.Return(ret)
 
@@ -792,7 +784,10 @@ async def test_req_chan_decode_data_dict_entry_v2_bad_signature(pki_dir):
     }
 
     with pytest.raises(salt.crypt.AuthenticationError) as excinfo:
-        ret = await client.crypted_transfer_decode_dictentry(load, dictkey="pillar",)
+        ret = await client.crypted_transfer_decode_dictentry(
+            load,
+            dictkey="pillar",
+        )
     assert "Pillar payload signature failed to validate." == excinfo.value.message
 
 
@@ -822,6 +817,7 @@ async def test_req_chan_decode_data_dict_entry_v2_bad_key(pki_dir):
     auth = client.auth
     auth._crypticle = salt.crypt.Crypticle(opts, AES_KEY)
     client.auth = MagicMock()
+    client.auth.mpub = auth.mpub
     client.auth.authenticated = True
     client.auth.get_keys = auth.get_keys
     client.auth.crypticle.dumps = auth.crypticle.dumps
@@ -875,7 +871,10 @@ async def test_req_chan_decode_data_dict_entry_v2_bad_key(pki_dir):
     }
 
     with pytest.raises(salt.crypt.AuthenticationError) as excinfo:
-        ret = await client.crypted_transfer_decode_dictentry(load, dictkey="pillar",)
+        ret = await client.crypted_transfer_decode_dictentry(
+            load,
+            dictkey="pillar",
+        )
     assert "Key verification failed." == excinfo.value.message
 
 
@@ -1278,3 +1277,70 @@ async def test_req_chan_auth_v2_new_minion_without_master_pub(pki_dir, io_loop):
     assert "sig" in ret
     ret = client.auth.handle_signin_response(signin_payload, ret)
     assert ret == "retry"
+
+
+async def test_when_async_req_channel_with_syndic_role_should_use_syndic_master_pub_file_to_verify_master_sig(
+    pki_dir,
+):
+    # Syndics use the minion pki dir, but they also create a syndic_master.pub
+    # file for comms with the Salt master
+    expected_pubkey_path = str(pki_dir.join("minion").join("syndic_master.pub"))
+    mockloop = MagicMock()
+    opts = {
+        "master_uri": "tcp://127.0.0.1:4506",
+        "interface": "127.0.0.1",
+        "ret_port": 4506,
+        "ipv6": False,
+        "sock_dir": ".",
+        "pki_dir": str(pki_dir.join("minion")),
+        "id": "syndic",
+        "__role": "syndic",
+        "keysize": 4096,
+    }
+    master_opts = dict(opts, pki_dir=str(pki_dir.join("master")))
+    server = salt.transport.zeromq.ZeroMQReqServerChannel(master_opts)
+    client = salt.transport.zeromq.AsyncZeroMQReqChannel(opts, io_loop=mockloop)
+
+    dictkey = "pillar"
+    target = "minion"
+    pillar_data = {"pillar1": "data1"}
+
+    # Mock auth and message client.
+    client.auth._authenticate_future = MagicMock()
+    client.auth._authenticate_future.done.return_value = True
+    client.auth._authenticate_future.exception.return_value = None
+    client.auth._crypticle = salt.crypt.Crypticle(opts, AES_KEY)
+    client.message_client = create_autospec(client.message_client)
+
+    @salt.ext.tornado.gen.coroutine
+    def mocksend(msg, timeout=60, tries=3):
+        client.message_client.msg = msg
+        load = client.auth.crypticle.loads(msg["load"])
+        ret = server._encrypt_private(
+            pillar_data, dictkey, target, nonce=load["nonce"], sign_messages=True
+        )
+        raise salt.ext.tornado.gen.Return(ret)
+
+    client.message_client.send = mocksend
+
+    # Note the 'ver' value in 'load' does not represent the the 'version' sent
+    # in the top level of the transport's message.
+    load = {
+        "id": target,
+        "grains": {},
+        "saltenv": "base",
+        "pillarenv": "base",
+        "pillar_override": True,
+        "extra_minion_data": {},
+        "ver": "2",
+        "cmd": "_pillar",
+    }
+    with patch(
+        "salt.crypt.verify_signature", autospec=True, return_value=True
+    ) as fake_verify:
+        ret = await client.crypted_transfer_decode_dictentry(
+            load,
+            dictkey="pillar",
+        )
+
+        assert fake_verify.mock_calls[0].args[0] == expected_pubkey_path
